<?php
class Posttype_Recipe_Metaboxes {
	public function __construct()
	{
		add_action( 'admin_menu', array(&$this,'remove_meta_box'), 0 );
		add_action( 'add_meta_boxes', array(&$this,'add_meta_box'), 0 );
		add_action( 'save_post', array(&$this,'meta_save'), 0 );
	}
    public function remove_meta_box()
    {
		remove_meta_box("tagsdiv-difficulty", 'recipe', 'side');
		remove_meta_box("tagsdiv-meal", 'recipe', 'side');
    }
    public function add_meta_box()
	{
		add_meta_box( 'recipe-information', 'Recipe Information', array(&$this,'recipe_information'),'recipe' ,'side','high');
		add_meta_box( 'recipe-ingredients', 'Ingredients', array(&$this,'recipe_ingredients'),'recipe' ,'normal','high');
	}
	public function recipe_information( $post )
	{
		do_action('cooked_recipe_info_metabox');
	}
	public function recipe_ingredients( $post )
	{
		do_action('cooked_recipe_ingredients_metabox');
	}
	public function meta_save( $post_id )
	{
	    $is_autosave = wp_is_post_autosave( $post_id );
	    $is_revision = wp_is_post_revision( $post_id );
	    $is_valid_nonce = ( isset( $_POST[ COOKED_PREFIX . 'nonce' ] ) && wp_verify_nonce( $_POST[ COOKED_PREFIX . 'nonce' ], COOKED_SLUG ) ) ? 'true' : 'false';
	 
	    // Exits script depending on save status
	    if ( $is_autosave || $is_revision || !$is_valid_nonce )
	    	return;

	    $fields = apply_filters('cooked_recipe_metabox_save_fields', array());
		foreach($fields as $field)
		{
			if( isset( $_POST[ $field ] ) )
			{
				update_post_meta( $post_id, $field, sanitize_text_field( $_POST[ $field ] ) );
			}
		}
		do_action('cooked_recipe_info_metabox_save');
	}
}
$Posttype_Recipe_Metaboxes = new Posttype_Recipe_Metaboxes;

add_filter('cooked_recipe_metabox_save_fields', 'cooked_recipe_info_metabox_save_fields', 1);

add_action('cooked_recipe_info_metabox', 'cooked_recipe_metabox_nonce',0);

add_action('cooked_recipe_info_metabox', 'cooked_recipe_info_metabox_difficulties',1);
add_action('cooked_recipe_info_metabox', 'cooked_recipe_info_metabox_meals',3);
add_action('cooked_recipe_info_metabox', 'cooked_recipe_info_metabox_servings',5);
add_action('cooked_recipe_info_metabox', 'cooked_recipe_info_metabox_yield',7);
add_action('cooked_recipe_info_metabox', 'cooked_recipe_info_metabox_prep_time',9);
add_action('cooked_recipe_info_metabox', 'cooked_recipe_info_metabox_cook_time',11);
add_action('cooked_recipe_info_metabox', 'cooked_recipe_info_metabox_total_time',13);

function cooked_recipe_info_metabox_save_fields($fields)
{
	$fields[] = 'servings';
	$fields[] = 'yield';
	$fields[] = 'cook_time';
	$fields[] = 'prep_time';
	$fields[] = 'total_time';
	return $fields;
}
function cooked_recipe_info_metabox_difficulties()
{
	global $post?>
	<p><?php
	    $difficulties = get_terms('difficulty',array('hide_empty' => 0, 'orderby' => 'ID', 'order' => 'ASC'));
	    $post_difficulties = get_the_terms( $post->ID, 'difficulty' );
	    $current_difficulty = ($post_difficulties ? array_pop($post_difficulties) : false);
	    $current_difficulty = ($current_difficulty ? $current_difficulty->term_id : 0);?>
		<label for="in-difficulty"><?php _e( 'Difficulty', 'cooked' ); ?></label><br/>
        <select id="in-difficulty" name="tax_input[difficulty]">
        	<option></option>
            <?php foreach($difficulties as $term):?>
                <option id="difficulty-<?php echo $term->term_id?>" value="<?php echo $term->name?>" <?php echo selected($current_difficulty,$term->term_id,false)?>>
                	<?php echo $term->name;?>
                </option> 
            <?php endforeach?>
      	</select></br>
		<span class="description"><?php _e( 'A rating of how difficult the recipe is.','cooked' ); ?></span>
	</p><?php
}
function cooked_recipe_info_metabox_meals()
{
	global $post?>
	<p><?php
	    $meals = get_terms('meal',array('hide_empty' => 0, 'orderby' => 'ID', 'order' => 'ASC'));
	    $post_meals = get_the_terms( $post->ID, 'meal' );
	    $current_meal = ($post_meals ? array_pop($post_meals) : false);
	    $current_meal = ($current_meal ? $current_meal->term_id : 0);?>
		<label for="in-meal"><?php _e( 'Meal', 'cooked' ); ?></label><br/>
        <select id="in-meal" name="tax_input[meal]">
        	<option></option>
            <?php foreach($meals as $term):?>
                <option id="meal-<?php echo $term->term_id?>" value="<?php echo $term->name?>" <?php echo selected($current_meal,$term->term_id,false)?>>
                	<?php echo $term->name;?>
                </option>
            <?php endforeach?>
      	</select></br>
		<span class="description"><?php _e( 'Meal the recipe is generally for.','cooked' ); ?></span>
	</p><?php
}
function cooked_recipe_info_metabox_servings()
{
	global $post?>
	<p>
		<?php $servings = get_post_meta($post->ID,'servings',TRUE)?>
		<label for="servings"><?php _e( 'Serves', 'cooked' ); ?></label><br/>
		<input type="text" name="servings" id="servings" value="<?php esc_attr_e($servings)?>" /></br>
		<span class="description"><?php _e( 'How many does this serve.','cooked' ); ?>
	</p><?php
}
function cooked_recipe_info_metabox_yield()
{
	global $post?>
	<p>
		<?php $yield = get_post_meta($post->ID,'yield',TRUE)?>
		<label for="yield"><?php _e( 'Yield', 'cooked' ); ?></label><br/>
		<input type="text" name="yield" id="yield" value="<?php esc_attr_e($yield)?>" /><br/>
		<span class="description"><?php _e( 'Enter the recipes yield.','cooked' ); ?></span>
	</p><?php
}
function cooked_recipe_info_metabox_cook_time()
{
	global $post?>
	<p>
		<?php $cook_time = get_post_meta($post->ID,'cook_time',TRUE)?>
		<label for="cook_time"><?php _e( 'Cook Time', 'cooked' ); ?></label><br/>
		<input type="text" name="cook_time" id="cook_time" class="timer" value="<?php esc_attr_e($cook_time)?>" /><br/>
		<span class="description"><?php _e( 'Enter the cook time.','cooked' ); ?></span>
	</p><?php
}
function cooked_recipe_info_metabox_prep_time()
{
	global $post?>
	<p>
		<?php $prep_time = get_post_meta($post->ID,'prep_time',TRUE)?>
		<label for="prep_time"><?php _e( 'Preparation Time', 'cooked' ); ?></label><br/>
		<input type="text" name="prep_time" id="prep_time" class="timer" value="<?php esc_attr_e($prep_time)?>" /><br/>
		<span class="description"><?php _e( 'Enter the prep time.','cooked' ); ?></span>
	</p><?php
}
function cooked_recipe_info_metabox_total_time()
{
	global $post?>
	<p>
		<?php $total_time = get_post_meta($post->ID,'total_time',TRUE)?>
		<label for="total_time"><?php _e( 'Time to Table', 'cooked' ); ?></label><br/>
		<input type="text" name="total_time" id="total_time" class="timer" value="<?php esc_attr_e($total_time)?>" /><br/>
		<span class="description"><?php _e( 'Enter the total time.','cooked' ); ?></span>
	</p><?php
}

function cooked_recipe_metabox_nonce()
{?>
	<input type="hidden" name="<?php echo COOKED_PREFIX?>nonce" value="<?php echo wp_create_nonce(COOKED_SLUG)?>"/><?php
}



add_action('cooked_recipe_ingredients_metabox', 'cooked_recipe_ingredients_metabox_rows',1);


function cooked_recipe_ingredients_metabox_rows()
{
	global $post, $wpdb;
	$query = new WP_Query( array(
		'post_type' => 'ingredient'/*
		'meta_key' => 'age',
		'orderby' => 'meta_value_num',
		'order' => 'ASC',
		'meta_query' => array(
			array(
				'key' => 'age',
				'value' => array(3, 4),
				'compare' => 'IN',
			)
		)*/
	) );
	$ingredients = array();
	$ingredient_list = array();
	while( $query->have_posts() ) : $query->next_post();
		$ingredients[$query->post->ID] = $query->post;
		$ingredient_list[$query->post->post_title] = $query->post->ID;
	endwhile?>
	<script type="text/javascript">
		var recipe_id = <?php echo $post->ID?>;
		var ingredient_edit_url = "<?php echo admin_url( 'post.php?action=edit' )?>";
		var ingredient_list = <?php echo json_encode($ingredient_list)?>;
		(function($){

			function addIngredientRow(data)
			{
				var table = $('#recipe-ingredient-list');
				var trow = $('<tr>').attr('id', "ingredient-row-" + data.ingredient.ID).data('ingredient_id', data.ingredient.ID).appendTo($('tbody',table));

				var tcol1 = $('<td>').appendTo(trow);
				var tcol2 = $('<td>').appendTo(trow);
				var actions = $('<td>').addClass('actions').appendTo(trow);

				var input1 = $('<input type="text" class="cooked-form-textfield form-textfield textfield" size="10" value="' + data.quantity + '" name="recipe_ingredients[' + data.ingredient.ID + '][quantity]" id="recipe_ingredients[' + data.ingredient.ID + '][quantity]"/>').appendTo(tcol1);
				var input2 = $('<input type="text" class="cooked-form-textfield form-textfield textfield" size="20" disabled="" value="' + data.ingredient.post_title + '" name="recipe_ingredients[' + data.ingredient.ID + '][post_title]" id="recipe_ingredients[' + data.ingredient.ID + '][post_title]"/>').appendTo(tcol2);

				var action3 = $('<a class="cooked-remove-ingredient-ajax button-secondary">X</a>').appendTo(actions);
			}

			$(document).ready(function(){
				$(function() {
					$("#add-ingredient-search").suggest(ajaxurl + '?action=cooked_ingredient_list');

					$(document).on('click', '#add-ingredient-button', function()
					{	
						var ingredient = $("#add-ingredient-search").val();
						
						var ajax_data = {
							'action' : 'cooked_add_recipe_ingredient'
						}
						ajax_data.recipe_id = recipe_id;
						ajax_data.quantity = $("#add-ingredient-quantity").val();

						if(ingredient_list[ingredient])
						{
							ajax_data.ingredient_id = ingredient_list[ingredient];
						}
						else
						{
							ajax_data.ingredient = {
								'post_title' : ingredient
							}
						}
						$.ajax({
							url: ajaxurl,
							type: "POST",
							data: ajax_data,
							dataType: 'json'
						})
						.done(function(data){
							ingredient = data.ingredient;
							ingredient_list[ingredient.post_title] = ingredient.ID;
							addIngredientRow(data);
							$("#add-ingredient-quantity, #add-ingredient-search").val('');
						});
					})

					$(document).on('click', '.cooked-remove-ingredient-ajax', function(){
						$this = $(this);
						
						$.ajax({
								url: ajaxurl,
								type: "POST",
								data: {
									'action' : 'cooked_remove_recipe_ingredient',
									'recipe_id' : recipe_id,
									'ingredient_id' : $this.parents('tr:first').data('ingredient_id'),
								},
								dataType: 'json'
						})
						.done(function(data){
							if(data.success)
							{
								$this.parents('tr:first').remove();
							}
						});
					});
				});
			})
		})(jQuery);
	</script>
    <div class="cooked-table-wrapper">
        <table id="recipe-ingredient-list" class="tablesorter cooked_table_sortable" style="width:100%;">
            <thead>
                <tr>
                	<th style="text-align:left;">Quantity</th>
                	<th style="text-align:left;" class="cooked-sortable">Ingredient</th>
                    <th></th>
                </tr>
                <tr>
                	<td style="border-bottom:2px solid #ccc; padding-bottom:.25em;">
                		<input type="text" id="add-ingredient-quantity" size="10"/>
                	</td>
                	<td style="border-bottom:2px solid #ccc; padding-bottom:.25em;">
						<input type="text" id="add-ingredient-search" size="20"/>
                	</td>
                	<td style="border-bottom:2px solid #ccc; padding-bottom:.25em;">
						<a id="add-ingredient-button" class="button-secondary">+</a>
                	</td>
                </tr>
            </thead>
            <tbody>
            <?php
				$recipe_ingredients = $wpdb->get_results( 
					"
					SELECT * 
					FROM " . COOKED_DB_TABLE . "
					WHERE recipe_id = '" . $post->ID . "'
					"
				);
				foreach($recipe_ingredients as $recipe_ingredient)
				{
					$ingredient = $ingredients[$recipe_ingredient->ingredient_id]?>
					<tr data-ingredient_id="<?php echo $recipe_ingredient->ingredient_id?>">
						<td><input type="text" class="cooked-form-textfield form-textfield textfield" size="10" value="<?php echo $recipe_ingredient->quantity?>" name="recipe_ingredients[<?php echo $recipe_ingredient->id?>][quantity]" id="recipe_ingredients[<?php echo $recipe_ingredient->id?>][quantity]"/></td>
						<td><input type="text" class="cooked-form-textfield form-textfield textfield" size="20" disabled="" value="<?php echo $ingredient->post_title?>" name="recipe_ingredients[<?php echo $recipe_ingredient->id?>][post_title]" id="recipe_ingredients[<?php echo $recipe_ingredient->id?>][post_title]"/></td>
						<td>
							<a class="cooked-remove-ingredient-ajax button-secondary">X</a>
						</td>
					</tr><?php
				}?>
			</tbody>
        </table>
    </div><?php
	// Restore original Post Data
	wp_reset_postdata();
}



